import * as React from "react";
import {remote} from "electron";
import * as fs from "fs";

const dialog = remote.dialog;

interface AppState {
    text?:string;
}

export class App extends React.Component<{}, AppState>  {
    constructor(props:any) {
        super(props);
        this.state = {
            text:""
        };

        this.onOpenClick = this.onOpenClick.bind(this);
        this.onSaveClick = this.onSaveClick.bind(this);
        this.onChangeText = this.onChangeText.bind(this);
    }

    // 開くボタンを押した時の処理
    onOpenClick(e:React.MouseEvent<HTMLButtonElement>) {
        // ファイルオープンダイアログを表示する
        dialog.showOpenDialog(remote.getCurrentWindow(), {
            filters:[
                { name: "Text File", extensions:["txt"]},
                { name: "All Files", extensions: ["*"]}
            ],
            properties: ["openFile"]
        }, filePaths=>{
            if(filePaths.length != 0) {
                // ファイル読み込み
                fs.readFile(filePaths[0], { encoding:"utf-8"}, (err, data)=>{
                    if(err) {
                        alert(err);
                    } else {
                        this.setState({text:data});
                    }
                });
            }
        });
    }

    // 保存ボタンを押した時の処理
    onSaveClick(e:React.MouseEvent<HTMLButtonElement>) {
        // ファイル保存ダイアログを表示する
        dialog.showSaveDialog(remote.getCurrentWindow(), {
            filters:[
                { name: "Text File", extensions:["txt"]},
                { name: "All Files", extensions: ["*"]}
            ]}, filename=>{
                if(filename) {
                    // ファイルに保存
                    fs.writeFile(filename, this.state.text, err=>{
                        if(err) {
                            alert(err);
                        }
                    });
                }
            });
    }
    onChangeText(e:React.ChangeEvent<HTMLTextAreaElement>) {
        this.setState({text:e.target.value});
    }

    render() {
        return <div>
            <p>
            <button type="button" onClick={this.onOpenClick}>開く</button>
            <button type="button" onClick={this.onSaveClick}>保存</button>
            </p>
            <p><textarea value={this.state.text} rows={30} cols={100} onChange={this.onChangeText}/></p>
            </div>;
    }
}

