const webpackMerge = require('webpack-merge');
const copyWebpackPlugin = require('copy-webpack-plugin');

// ベースのコンパイル設定
baseConfig = {   
  module: {
    rules: [
      {
        // 拡張子 .tsもしくは.tsx の場合
        test: /\.tsx?$/,
        // TypeScript をコンパイルする
        use: "ts-loader"
      }
    ]
  },
  // import 文で .ts ファイルを解決するため
  resolve: {
    extensions: [
      ".ts", ".tsx", ".js", ".json"
    ]
  }
};

// レンダラープロジェクトのコンパイル設定
rendererConfig = webpackMerge(baseConfig, {   
    entry: "./src/renderer/index.tsx",

    target: "electron-renderer",

    output: {
        path:`${__dirname}/dist`,
        filename: "app.js"
    },
    plugins: [
      new copyWebpackPlugin([
        { from: "./src/*.html", to:"[name].[ext]" },
        { from: "./src/package.json" },
      ])
    ]  
});

// メインプロセスのコンパイル設定
mainConfig = webpackMerge(baseConfig, {   
  entry: "./src/main/main.ts",
  
  target: "electron-main",

  output: {
      path:`${__dirname}/dist`,
      filename: "main.js"
  },
  node: {
      console:true,
      __dirname:false,
      __filename:false
  }
});

module.exports = [ rendererConfig, mainConfig];